==> banshee-1-0.98.1.tar.gz: banshee-1-0.98.1/src/Core/Banshee.Services/Banshee.Sources/ITrackModelSource.cs <==
//
// ITrackModelSource.cs
//
// Author:
//   Aaron Bockover <abockover@novell.com>
//
// Copyright (C) 2007 Novell, Inc.
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
//
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;
using System.Collections.Generic;

using NDesk.DBus;

using Banshee.Collection;

namespace Banshee.Sources
{
    public interface ITrackModelSource : ISource
    {
        TrackListModel TrackModel { get; }
        AlbumListModel AlbumModel { get; }
        ArtistListModel ArtistModel { get; }

        void Reload ();
        bool HasDependencies { get; }

        void RemoveSelectedTracks ();
        void DeleteSelectedTracks ();

        bool CanRemoveTracks { get; }
        bool CanDeleteTracks { get; }
        bool ConfirmRemoveTracks { get; }
        
        bool ShowBrowser { get; }
    }
}

==> banshee-1-0.99.3.tar.gz: banshee-1-0.99.3/src/Core/Banshee.Services/Banshee.Sources/ITrackModelSource.cs <==
//
// ITrackModelSource.cs
//
// Author:
//   Aaron Bockover <abockover@novell.com>
//
// Copyright (C) 2007 Novell, Inc.
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
//
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;
using System.Collections.Generic;

using NDesk.DBus;

using Banshee.Collection;

namespace Banshee.Sources
{
    public interface ITrackModelSource : ISource
    {
        TrackListModel TrackModel { get; }
        
        IEnumerable<Banshee.Collection.Database.IFilterListModel> FilterModels { get; }
        
        //AlbumListModel AlbumModel { get; }
        //ArtistListModel ArtistModel { get; }

        void Reload ();
        bool HasDependencies { get; }

        void RemoveSelectedTracks ();
        void DeleteSelectedTracks ();

        bool CanAddTracks { get; }
        bool CanRemoveTracks { get; }
        bool CanDeleteTracks { get; }
        bool ConfirmRemoveTracks { get; }
        
        bool ShowBrowser { get; }
    }
}
